summaryrefslogtreecommitdiffstats
path: root/chrome/common/mac/app_mode_common.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/mac/app_mode_common.h')
-rw-r--r--chrome/common/mac/app_mode_common.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/common/mac/app_mode_common.h b/chrome/common/mac/app_mode_common.h
index d397c4b..de82e24 100644
--- a/chrome/common/mac/app_mode_common.h
+++ b/chrome/common/mac/app_mode_common.h
@@ -29,9 +29,10 @@ extern const char kAppShimSocketName[];
// Special app mode id used for the App Launcher.
extern const char kAppListModeId[];
-// Instructs the app shim to send LaunchApp with launch_now = false. This
-// associates the shim without launching the app.
-extern const char kNoLaunchApp[];
+// The process ID of the Chrome process that launched the app shim.
+// The presence of this switch instructs the app shim to send LaunchApp with
+// launch_now = false. This associates the shim without launching the app.
+extern const char kLaunchedByChromeProcessId[];
// The display name of the bundle as shown in Finder and the Dock. For localized
// bundles, this overrides the bundle's file name.